### ブラウン運動のシミュレーション
## シミュレーターの作成
## サンプル時点数nと区間の終端Terminalが与えられたとき,
## 区間[0,T]上のブラウン運動をシミュレーションする
simulateBM <- function(n, Terminal = 1){ # Terminalは既定値を1に設定
  Z <- rnorm(n) # 標準正規乱数の生成
  Bt <- diffinv(Z)/sqrt(n) # Btのサンプルパス
  return(Bt)
}
## モンテカルロ・シミュレーションの実行
set.seed(123) # 乱数シードの固定
MC <- 100 # シミュレーション回数
n <- 1000 # 区間の分割数
result <- replicate(MC, simulateBM(n)) # シミュレーション
Time <- seq(0, 1, by = 1/n) # サンプル時点
matplot(Time, result, type = "l", lty = 1, col = "gray",
        xlab = "t", ylab = "B(t)") # シミュレーションしたサンプルパスの描画
