### F分布を不変分布にもつ拡散過程
## 確率微分方程式モデルの定義
mod <- setModel(drift = "-theta*(x-beta/(beta-2))", # ドリフト係数
                diffusion = "sqrt(4*theta*x*(beta+alpha*x)/(alpha*(beta-2)))" # 拡散係数
)
## サンプル時点の定義
n <- 1000
samp <- setSampling(n = n)
## 統計モデルの定義
smod <- setYuima(model = mod, sampling = samp)
## シミュレーターの作成
mysim <- function(theta, alpha, beta){
  param <- list(theta = theta, alpha = alpha, beta = beta)
  out <- simulate(smod, 
                  xinit = rf(1, df1 = alpha, df2 = beta), # 不変分布から初期値を生成
                  true.parameter = param)
  XT <- tail(get.zoo.data(out)[[1]], n = 1) # 最後の観測値を取り出す
  return(XT)
}
## シミュレーション
set.seed(123)
MC <- 2000
result <- replicate(MC, mysim(theta = 1, alpha = 10, beta = 10))
hist(result, freq = FALSE, breaks = 50,
     xlab = "X(1)", main = "Histogram of X(1)",
     col = "darkgray", border = "cyan")
curve(df(x,df1=10,df2=10), add = TRUE, col="red",lwd=2)
