### へストンモデルのシミュレーション
## 確率微分方程式モデルの定義
drift <- c("mu*S", "-theta*(V-v)") # ドリフト係数
diffusion <- matrix(c("sqrt(max(V,0))*S", 
                      "gamma*sqrt(max(V,0))*rho",
                      0,
                      "gamma*sqrt(max(V,0))*sqrt(1-rho^2)"),
                    2,2) # 拡散係数
mod <- setModel(drift = drift, diffusion = diffusion,
                state.variable = c("S", "V") # 状態変数
                )
## サンプル時点の定義
samp <- setSampling(n = 1000)
## 統計モデルの定義
heston <- setYuima(model = mod, sampling = samp)
## シミュレーションとサンプルパスの描画
set.seed(100)
x0 <- c(1, 0.1) # 初期値
param <- list(mu = 0.03, theta = 3, v = 0.09, 
              gamma = 0.3, rho = -0.6) # パラメーターの値
# シミュレーションの実行
result <- simulate(heston, # 統計モデル
                   xinit = x0, # 初期値
                   true.parameter = param # パラメーターの値
)
plot(result, col = c("red", "blue"), lwd = 2)