### ヤコビ過程のシミュレーション
## 確率微分方程式モデルの定義
## 拡散係数に現れる平方根の中では, 負に評価された値を0と読みかえるようにする
mod <- setModel(drift = "-theta*(x-mu)", # ドリフト係数
                diffusion = "sigma * sqrt(max(x*(1-x), 0))" 
                # 拡散係数
)
## サンプル時点の定義
n <- 1000
samp <- setSampling(n = n)
## 統計モデルの定義
jacobi <- setYuima(model = mod, sampling = samp)
## シミュレーションとサンプルパスの描画
set.seed(123)
x0 <- 0.2 # 初期値
param <- list(theta = 8, mu = 0.1, sigma = 0.4) # パラメーターの値
# シミュレーションの実行
result <- simulate(jacobi, # 統計モデル
                   xinit = x0, # 初期値
                   true.parameter = param # パラメーターの値
)
plot(result, col = "royalblue", lwd = 2)
grid(col = "darkgray") # グリッドの追加
