### オルンシュタイン・ウーレンベック過程の周辺分布
## シミュレーターの作成
simulateXT <- function(smod, x0, param){
  out <- simulate(smod, xinit = x0, true.parameter = param)
  XT <- tail(get.zoo.data(out)[[1]], n = 1) # 最後の観測値を取り出す
  return(XT)
}
## パラメーターの設定
x0 <- 0.1 # 初期値
theta <- 3 # 平均回帰スピード
mu <- 0.09 # 平均回帰レベル
sigma <- 0.3 # ボラティリティ
param <- list(theta = theta, mu = mu, sigma = sigma)
## モンテカルロ・シミュレーションの実行
set.seed(123) # 乱数シードの固定
MC <- 2000 # シミュレーション回数
result <- replicate(MC, simulateXT(ou, x0, param)) # シミュレーション
## ヒストグラムの描画
hist(result, freq = FALSE, breaks = 20,
     xlab = "X(1)", main = "Histogram of X(1)",
     col = "darkgray", border = "cyan")
## 理論分布の上書き
t.mu <- x0 * exp(-theta) + mu * (1 - exp(-theta)) # 理論上の平均
t.var <- (sigma^2/(2*theta)) * (1 - exp(-2*theta)) # 理論上の分散
curve(dnorm(x, t.mu, sqrt(t.var)), add = TRUE, 
      col="red", lwd = 2)
