### オルンシュタイン・ウーレンベック過程の平均回帰スピードの比較
## サンプル時点の定義
n <- 1000 # サンプル時点数
samp <- setSampling(Terminal = 10, # 終端時点
                    n = n # サンプル時点数
)
Time <- samp@grid[[1]] # サンプル時点
## 統計モデルの定義
ou <- setYuima(model = mod.ou, # 確率微分方程式モデル
               sampling = samp # サンプリング時点
)
## パラメーターの設定
x0 <- 0.1 # 初期値
theta <- c(0.03, 3, 30) # 平均回帰スピードの候補ベクトル
mu <- 0.09 # 平均回帰レベル
sigma <- 0.3 # ボラティリティ
## シミュレーション
set.seed(123) # 乱数シードの固定
result <- matrix(0, n + 1, length(theta)) # 結果を保持する行列
for(i in 1:length(theta)){
  param <- list(theta = theta[i], mu = mu, sigma = sigma)
  out <- simulate(ou, xinit = x0, true.parameter = param)
  result[ ,i] <- get.zoo.data(out)[[1]]
}
## プロット
matplot(Time, result, type = "l", lty = 1, 
        col = topo.colors(length(theta)), 
        xlab = "t", ylab = "X(t)")
abline(h = mu, col = "red", lwd = 2, lty = "dotted") # 平均回帰レベル
grid(col = "darkgray") # グリッドの追加
## 凡例の追加
legend(0.5, 0.8, legend = paste("theta =", theta),
       lty = 1, col = topo.colors(length(theta)), bty = "n")
