### オルンシュタイン・ウーレンベック過程のシミュレーション
## 確率微分方程式モデルの定義
mod.ou <- setModel(drift = "-theta*(x-mu)", # ドリフト係数
                   diffusion = "sigma" # 拡散係数
)
## サンプル時点の定義
n <- 1000 # サンプル時点数
samp <- setSampling(n = n)
## 統計モデルの定義
ou <- setYuima(model = mod.ou, # 確率微分方程式モデル
               sampling = samp # サンプル時点
)
## シミュレーションとサンプルパスの描画
set.seed(123)
x0 <- 0.1 # 初期値
param <- list(theta = 3, mu = 0.09, sigma = 0.3) # パラメーターの値
# シミュレーションの実行
result <- simulate(ou, # 統計モデル
                   xinit = x0, # 初期値
                   true.parameter = param # パラメーターの値
)
plot(result, col = "darkgray")
grid(col = "darkgray") # グリッドの追加