### 確率積分の二次変動の収束
### 二次変動は時点0,0.1,...,0.9,1で評価
n <- 10000 # サンプル時点数
# (二次変動の評価時点より細かく取っておく)
set.seed(123) # 乱数シードの固定
B <- simulateBM(n) # Brown運動のシミュレーション
X <- diffinv(B[1:n] * diff(B)) # 確率積分を近似するリーマン和の計算
qv <- diffinv(diff(X)^2) # 二次変動の計算
qv <- qv[seq(1, n+1, by = 1000)] # 評価時点のみ残す
qv.true <- diffinv(B[1:n]^2/n) # 理論値の計算
qv.true <- qv.true[seq(1, n+1, by = 1000)] # 評価時点のみ残す
plot(qv ~ qv.true, pch = 19, xlab = "Theoretical QV", 
     ylab = "Empirical QV") # 理論値 vs 観測値の散布図
abline(0, 1, lty = "dotted", col = "red", lwd = 2) # 45度線