### 確率積分を定義するリーマン和の収束
## ブラウン運動のシミュレーション
set.seed(123) # 乱数シードの固定
n <- 10000 # サンプル時点数
B <- simulateBM(n) # サンプルパスのシミュレーション
## サブサンプルしたデータのリーマン和を計算してプロット
ns <- 10^(1:4) # サブサンプリングする時点数(10,100,1000,10000)
result <- double(length(ns)) # 結果を保持するためのベクトル
for(i in 1:length(ns)){
  subB <- B[seq(1, n+1, length = ns[i]+1)] # サブサンプリング
  result[i] <- sum(subB[1:ns[i]] * diff(subB)) # リーマン和の計算
}
plot(ns, result, type = "b", pch = 8,
     xlab = "Number of subsamples",
     ylab = "Riemann sum") # プロット
abline(h = (B[length(B)]^2 - 1)/2, col = "red",
       lty = "dotted", lwd = 2) # 理論値