### SABRモデルのシミュレーション
## 確率微分方程式モデルの定義
drift <- c(0, 0) # ドリフト係数
diffusion <- matrix(c("alpha*max(X,0)^beta", 
                      "nu*alpha*rho",
                      0,
                      "nu*alpha*sqrt(1-rho^2)"),
                    2,2) # 拡散係数
mod <- setModel(drift = drift, diffusion = diffusion,
                state.variable = c("X", "alpha") # 状態変数
)
## サンプル時点の定義
samp <- setSampling(n = 1000)
## 統計モデルの定義
sabr <- setYuima(model = mod, sampling = samp)
## シミュレーションとサンプルパスの描画
set.seed(100)
x0 <- c(1, 0.15) # 初期値
param <- list(beta = 0.6, nu = 0.35, rho = -0.6) # パラメーターの値
# シミュレーションの実行
result <- simulate(sabr, # 統計モデル
                   xinit = x0, # 初期値
                   true.parameter = param # パラメーターの値
)
plot(result, col = c("red", "blue"), lwd = 2)