### yuimaパッケージによる確率微分方程式のシミュレーション
library(yuima) # パッケージのロード
## 確率微分方程式モデルの定義
mod <- setModel(drift = "-theta*x", # ドリフト係数
                diffusion = "1/(1+x^2)", # 拡散係数
                state.variable = "x" # 状態変数(既定値が"x"のため省略可)
)
str(mod) # モデルを表すオブジェクトの構造
## サンプル時点の定義
n <- 1000
samp <- setSampling(Initial = 0, # 初期時点(既定値が0なので省略可)
                    Terminal = 1, # 終端時点(既定値が1なので省略可)
                    n = n # サンプリング時点数(初期時点は除く)
)
str(samp) # サンプル時点を表すモデルの構造
## 統計モデルの定義
smod <- setYuima(model = mod, # 確率微分方程式モデル
                 sampling = samp # サンプリング時点
)
str(samp) # 統計モデルを表すモデルの構造
## シミュレーションとサンプルパスの描画
set.seed(123) # 乱数シードの固定
x0 <- 0 # 初期値
param <- list(theta = 3) # パラメーターの値
# シミュレーションの実行
result <- simulate(smod, # 統計モデル
                   xinit = x0, # 初期値
                   true.parameter = param # パラメーターの値
)
plot(result, col = "darkgray") # プロット