### t分布を不変分布にもつ拡散過程
## 確率微分方程式モデルの定義
mod <- setModel(drift = "-theta*x", # ドリフト係数
                diffusion = "sqrt(2*theta*(nu+x^2)/(nu-1))" # 拡散係数
)
## サンプル時点の定義
n <- 1000
samp <- setSampling(n = n)
## 統計モデルの定義
smod <- setYuima(model = mod, sampling = samp)
## シミュレーターの作成
mysim <- function(theta, nu){
  param <- list(theta = theta, nu = nu)
  out <- simulate(smod, 
                  xinit = rt(1, df = nu), # 不変分布から初期値を生成
                  true.parameter = param)
  XT <- tail(get.zoo.data(out)[[1]], n = 1) # 最後の観測値を取り出す
  return(XT)
}
## シミュレーション
set.seed(123)
MC <- 2000
result <- replicate(MC, mysim(theta = 10, nu = 8))
hist(result, freq = FALSE, breaks = 50,
     xlab = "X(1)", main = "Histogram of X(1)",
     col = "darkgray", border = "cyan")
curve(dt(x,df=8), add = TRUE, col="red", lwd = 2)
