### ウィーナー積分が正規分布に従うことの確認
## シミュレーターの作成
# ウィーナー積分を離散化する時点数nを引数として, 
# 対応するリーマン和をシミュレート
wiener.integral <- function(n){
  B <- simulateBM(n) # ブラウン運動のシミュレーション
  return(sum(seq(0, 1 - 1/n, by = 1/n) * diff(B)))
}
## モンテカルロ・シミュレーションの実行
set.seed(123) # 乱数シードの固定
MC <- 10000 # シミュレーション回数
n <- 1000 # サンプル時点数
result <- replicate(MC, wiener.integral(n)) # シミュレーション
## ヒストグラムの描画
hist(result, freq = FALSE, breaks = 50, main = "",
     xlab = expression(integral(t*dB(t),0,1)), 
     col = "lightblue", border = "lightblue")
curve(dnorm(x, sd = 1/sqrt(3)), add = TRUE, col="red", 
      lwd = 2) # 理論上の確率密度関数
