### yuimaパッケージによる幾何ブラウン運動のシミュレーション
library(yuima) # パッケージのロード
## 確率微分方程式モデルの定義
mod <- setModel(drift = "mu*x", # ドリフト係数
                diffusion = "sigma*x", # 拡散係数
                state.variable = "x" # 状態変数
)
## サンプル時点の定義(区間[0,1]上でシミュレート)
n <- 1000 # サンプル時点数
samp <- setSampling(n = n)
## 統計モデルの定義
gbm <- setYuima(model = mod, # 確率微分方程式モデル
                sampling = samp # サンプリング時点
)
## シミュレーション
set.seed(123)
x0 <- 1 # 初期値
param <- list(mu = 0.4, sigma = 0.4) # パラメーターの値
# ここでは後で解析解と結果を比較したいため, あらかじめ駆動する
# ブラウン運動の増分をシミュレーションしておく
dB <- rnorm(n)/sqrt(n)
# シミュレーションの実行
result <- simulate(gbm, # 統計モデル
                   xinit = x0, # 初期値
                   true.parameter = param, # パラメーターの値
                   increment.W = matrix(dB,1,n) 
                   # 駆動するブラウン運動の増分(技術的な理由から行列に変換)
)
plot(result, col = "darkgray")